# Interactive JSON queries, built on prompt toolkit and jmespath
![Example](./demo.gif)

## Installation
Recommended installation is with [pipx](https://github.com/pypa/pipx):
```bash
python3 -m pip install --user pipx
python3 -m pipx ensurepath
python3 -m pipx install ptijson
```
